package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.ContractDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.ContractDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.ContractDataRequest;
import cn.com.ty.lift.batch.applet.util.DataStatisticsUtil;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class ContractDataService {

    @Resource
    private ContractDataMapper contractDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 结束时间
     * @return
     * @description 将合同数据放入redis中
     * @date 2020/2/4 11:17 上午
     */
    public void putContractDataToRedis(CommonRequest commonRequest) {
        List<ContractDataModel> contractDataModelList = contractDataMapper.getContractDataList(commonRequest);
        //通过公司id给数据分组
        DataStatisticsUtil.putStatisticsDataToRedis(contractDataModelList, redisTemplate,
                DataStatisticsConstants.CONTRACT_DATA_FIELD);
    }

    /**
     * @param contractDataRequest 起始时间 终止时间
     * @return
     * @description 获取合同数据
     * @date 2020/2/4 11:47 上午
     */
    public List<ContractDataModel> getContractDataListFromRedis(ContractDataRequest contractDataRequest) {
        //从redis中获取当前公司合同数据
        List<ContractDataModel> contractDataModelList = (List<ContractDataModel>) DataStatisticsUtil
                .getStatisticsDataFromRedis(redisTemplate,
                        DataStatisticsConstants.CONTRACT_DATA_FIELD, contractDataRequest.getMtCompanyId());
        return contractDataModelList;
    }

    /**
     * @param
     * @return
     * @description 合同总览
     * @date 2020/2/5 4:35 下午
     */
    public RestResponse contractOverView(ContractDataRequest contractDataRequest) {
        List<ContractDataModel> contractDataModelList = getContractDataListFromRedis(contractDataRequest);
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }

    /**
     * @param
     * @return
     * @description 丢失合同统计
     * @date 2020/2/5 4:39 下午
     */
    public RestResponse lostContract(ContractDataRequest contractDataRequest) {
        List<ContractDataModel> contractDataModelList = getContractDataListFromRedis(contractDataRequest);
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }

    /**
     * @param
     * @return
     * @description 到期预警
     * @date 2020/2/5 4:41 下午
     */
    public RestResponse dueToWarn(ContractDataRequest contractDataRequest) {
        List<ContractDataModel> contractDataModelList = getContractDataListFromRedis(contractDataRequest);
        return RestResponse.success(ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }
}
